package com.javapointers.sikuli;

import org.sikuli.script.FindFailed;
import org.sikuli.script.Key;
import org.sikuli.script.KeyModifier;
import org.sikuli.script.Screen;

import java.net.URISyntaxException;
import java.net.URL;

public class SikuliAutomation {

    private Screen screen;
    private String basePath;

    public SikuliAutomation() throws URISyntaxException {
        screen = new Screen();
        URL resourceFolderURL = this.getClass().getClassLoader().getResource("images");
        basePath = resourceFolderURL.toURI().getPath() + "/";
    }

    private void startTest() throws FindFailed {
        clickWindowsStartAndOpenMSWord();
        typeTextInWordAndSave();
    }

    private void clickWindowsStartAndOpenMSWord() throws FindFailed {
        screen.click(basePath + "windows-start.png");
        screen.wait(1.0); //need delay to allow animation to bring start menu
        screen.type("word");
        screen.wait(1.0); //wait for 1 second to show results
        screen.type(Key.ENTER);
    }

    private void typeTextInWordAndSave() throws FindFailed {
        screen.click(basePath + "blank-document.png");
        screen.type("This is a test in Sikuli Automation by JavaPointers.");
        screen.type("s", KeyModifier.CTRL);
        screen.click(basePath + "browse-save.png");
        screen.type("sikuli-test-document");
        screen.click(basePath + "btn-save.png");
    }

    public static void main(String... args) throws FindFailed, URISyntaxException {
        SikuliAutomation sikuliAutomation = new SikuliAutomation();
        sikuliAutomation.startTest();
    }
}
